import {
  createLabeledInputNumber,
  createLabeledTextarea,
  createLabeledDropdown,
  SwitchButtonView,
  ViewModel,
  addListToDropdown,
} from 'ckeditor5/src/ui';
import TableFormView from './baseFormView';

// Header Field
const headerOptions = [
  {id: 'none', label: 'None'},
  {id: 'first_row', label: 'First Row'},
  {id: 'first_column', label: 'First Column'},
  {id: 'both', label: 'Both'},
];

export default class MainTableFormView extends TableFormView {
  constructor(locale, editor) {
    super(locale, {headerLabel: 'Table Properties'});
    this.locale = locale;
    this.editor = editor;

    // Create form fields
    this.rowsInputView = this._createInput('Rows', createLabeledInputNumber, {placeholder: '2'});
    this.columnsInputView = this._createInput('Columns', createLabeledInputNumber, {placeholder: '2'});

    this.headerRowsView = this._createDropdown('Headers', headerOptions, 'select_header');

    const styleOptions = editor.config._config.tableStyles;
    this.classOptionsView = this._createDropdown('Stylesheet Class', styleOptions, 'select_style');

    // Build form structure
    this.addRow([this.rowsInputView, this.columnsInputView]);
    this.addRow([this.headerRowsView]);

    if (styleOptions.length) {
      this.addRow([this.classOptionsView]);
    }

    this.addActionRow();

    // Setup event handlers
    this._setupEventHandlers();
  }

  _registerFocusableViews() {
    [
      this.rowsInputView,
      this.columnsInputView,
      this.headerRowsView,
      this.classOptionsView,
      this.saveButtonView,
      this.cancelButtonView,
    ].forEach(view => {
      this._focusables.add(view);
      this.focusTracker.add(view.element);
    });
  }

  _setupEventHandlers() {
    this.classOptionsView.fieldView.on('execute', evt => {
      const {id, label} = evt.source;
      this.classOptionsViewValue = id;
      this.classOptionsView.fieldView.buttonView.label = label;
      this.classOptionsView.fieldView.class = 'ck-dropdown-selected';
    });

    this.headerRowsView.fieldView.on('execute', evt => {
      const {id, label} = evt.source;
      this.headerRowsViewValue = id;
      this.headerRowsView.fieldView.buttonView.label = label;
      this.headerRowsView.fieldView.class = 'ck-dropdown-selected';
    });

  }
}
